@@ -5,6 +5,7 @@ import requests
 from pathlib import Path
 from slai.clients.model import get_model_client
 from slai.clients.project import get_project_client
+from slai.clients.cli import get_cli_client
 
 from slai_cli import log
 from slai_cli.errors import handle_error
@@ -16,12 +17,12 @@ from slai_cli.constants import MODEL_WATCH_INTERVAL_S
 from slai_cli.exceptions import RetryException
 
 
-def _upload_local_notebook(local_config_helper, model_client, model_name):
+def _upload_local_notebook(
+    local_config_helper, model_client, model_name, model_version
+):
     local_model_config = local_config_helper.get_local_model_config(
         model_name=model_name, model_client=model_client
     )
-    model_version_id = local_model_config.get("model_version_id")
-
     model_notebook_google_drive_file_id = local_model_config.get(
         "model_notebook_google_drive_file_id"
     )
@@ -34,7 +35,7 @@ def _upload_local_notebook(local_config_helper, model_client, model_name):
     model_notebook_google_drive_file_id = drive_client.upload_model_notebook(
         model_name=model_name,
         model_google_drive_folder_id=model_google_drive_folder_id,
-        notebook_path=f"{cwd}/models/{model_name}/{model_version_id}/notebook.ipynb",
+        notebook_path=f"{cwd}/models/{model_name}/{model_version['name']}/notebook.ipynb",
         file_id=model_notebook_google_drive_file_id,
     )
 
@@ -54,6 +55,8 @@ def open_model(model_name, watch):
     project_name = project["name"]
     project_id = project["id"]
 
+    cli_client = get_cli_client()
+
     try:
         model_client = get_model_client(
             model_name=model_name, project_name=project_name
@@ -70,13 +73,23 @@ def open_model(model_name, watch):
         model_name=model_name, model_client=model_client
     )
 
-    model_version_id = local_model_config["model_version_id"]
+    model_version_id = local_model_config.get("model_version_id")
+    if model_version_id is None:
+        model_version_id = model_client.model["model_version_id"]
+
+    model_version = cli_client.retrieve_model_version_by_id(
+        model_version_id=model_version_id
+    )
+
+    log.action(f"Opening model version: {model_version['name']} <{model_version_id}>")
+
     model_notebook_url = None
     if local_config_helper.drive_integration_enabled:
         model_notebook_url = _upload_local_notebook(
             local_config_helper=local_config_helper,
             model_client=model_client,
             model_name=model_name,
+            model_version=model_version,
         )
     else:
         try:
@@ -97,7 +110,7 @@ def open_model(model_name, watch):
             )
 
         if server_started:
-            model_notebook_url = f"http://localhost:{docker_client.host_port}/notebooks/models/{model_name}/{model_version_id}/notebook.ipynb"
+            model_notebook_url = f"http://localhost:{docker_client.host_port}/notebooks/models/{model_name}/{model_version['name']}/notebook.ipynb"  # noqa
             log.action("Waiting for notebook server to start...")
             time.sleep(5.0)
         else:
@@ -114,6 +127,7 @@ def open_model(model_name, watch):
         model_watching_thread = ModelWatcher(
             model_name=model_name,
             model_client=model_client,
+            model_version=model_version,
             google_drive_integration_enabled=local_config_helper.drive_integration_enabled,
         )
         model_watching_thread.daemon = True
